# `RGBMatrixDriver`

[![pypi Badge](https://img.shields.io/pypi/v/RGBMatrixDriver)](https://pypi.org/project/RGBMatrixDriver/)

`RGBMatrixDriver` is a driver middleware for `rpi-rgb-led-matrix`/`RGBMatrixEmulator` compatible display scripts.
